diff --git a/Fltk/Solvers.cpp b/Fltk/Solvers.cpp
index a7dd4321821d39f3cb4c47f810f50b2a6f7d7c00..391ca8aa91983013964245216940a4931d9b8785 100644
--- a/Fltk/Solvers.cpp
+++ b/Fltk/Solvers.cpp
@@ -82,7 +82,7 @@ int Solver(int num, const char *args)
 #if !defined(WIN32)
       command += " &";
 #endif
-      server->StartClient(command.c_str(), 0, 4.0);
+      server->StartClient(command.c_str());
       return 1;
     }
   }
@@ -125,7 +125,7 @@ int Solver(int num, const char *args)
 #endif
   }
 
-  int sock = server->StartClient(command.c_str(), sockname.c_str(), 4.0);
+  int sock = server->StartClient(command.c_str(), sockname.c_str());
 
   if(sock < 0) {
     switch (sock) {
diff --git a/Common/GmshSocket.h b/Common/GmshSocket.h
index 49d43be628b46740cc64d3fe7bbba67702bb9281..4513b11e1081c1324518ac3277b950729f7522a9 100644
--- a/Common/GmshSocket.h
+++ b/Common/GmshSocket.h
@@ -286,7 +286,7 @@ class GmshServer : public GmshSocket{
   virtual ~GmshServer(){}
   virtual int SystemCall(const char *str) = 0;
   virtual int NonBlockingWait(int socket, int num, double waitint) = 0;
-  int StartClient(const char *command, const char *sockname=0, int maxdelay=4)
+  int StartClient(const char *command, const char *sockname=0, int timeout=5)
   {
     bool justwait = (!command || !strlen(command));
     _sockname = sockname;
@@ -365,9 +365,9 @@ class GmshServer : public GmshSocket{
       }
     }
     else{
       // Wait at most maxdelay seconds for data, issue error if no
       // connection in that amount of time
-      if(!Select(tmpsock, maxdelay, 0)){
+      if(!Select(tmpsock, timeout, 0)){
         CloseSocket(tmpsock);
         return -4;  // Error: Socket listening timeout
       }
@@ -365,9 +365,9 @@ class GmshServer : public GmshSocket{
     }
     else{
-      // Wait at most maxdelay seconds for data, issue error if no
+      // Wait at most timeout seconds for data, issue error if no
       // connection in that amount of time